@@ -137,7 +137,7 @@ static char *home_dir;
 
 static volatile sig_atomic_t fvwmRunState = FVWM_RUNNING;
 
-static const char *initFunctionNames[4] =
+static const char *init_function_names[4] =
 {
 	"InitFunction",
 	"RestartFunction",
@@ -319,7 +319,7 @@ SigDone(int sig)
 }
 
 /*
- * parseCommandArgs - parses a given command string into a given limited
+ * parse_command_args - parses a given command string into a given limited
  * argument array suitable for execv*. The parsing is similar to shell's.
  * Returns:
  *   positive number of parsed arguments - on success,
@@ -338,121 +338,121 @@ SigDone(int sig)
  * on the next function call. This can be changed using dynamic allocation,
  * in this case the caller must free the string pointed by argv[0].
  */
-static int parseCommandArgs(
-	const char *command, char **argv, int maxArgc, const char **errorMsg)
+static int parse_command_args(
+	const char *command, char **argv, int max_argc, const char **error_msg)
 {
 	/* It is impossible to guess the exact length because of expanding */
 #define MAX_TOTAL_ARG_LEN 256
-	/* char *argString = safemalloc(MAX_TOTAL_ARG_LEN); */
-	static char argString[MAX_TOTAL_ARG_LEN];
-	int totalArgLen = 0;
-	int errorCode = 0;
+	/* char *arg_string = safemalloc(MAX_TOTAL_ARG_LEN); */
+	static char arg_string[MAX_TOTAL_ARG_LEN];
+	int total_arg_len = 0;
+	int error_code = 0;
 	int argc;
-	char *aptr = argString;
+	char *aptr = arg_string;
 	const char *cptr = command;
 
-#define theChar (*cptr)
-#define advChar (cptr++)
-#define topChar (*cptr     == '\\'? *(cptr+1): *cptr)
-#define popChar (*(cptr++) == '\\'? *(cptr++): *(cptr-1))
-#define canAddArgChar (totalArgLen < MAX_TOTAL_ARG_LEN-1)
-#define addArgChar(ch) (++totalArgLen, *(aptr++) = ch)
-#define canAddArgStr(str) (totalArgLen < MAX_TOTAL_ARG_LEN-strlen(str))
-#define addArgStr(str) \
+#define the_char (*cptr)
+#define adv_char (cptr++)
+#define top_char (*cptr     == '\\' ? *(cptr + 1) : *cptr)
+#define pop_char (*(cptr++) == '\\' ? *(cptr++) : *(cptr - 1))
+#define can_add_arg_char (total_arg_len < MAX_TOTAL_ARG_LEN-1)
+#define add_arg_char(ch) (++total_arg_len, *(aptr++) = ch)
+#define can_add_arg_str(str) (total_arg_len < MAX_TOTAL_ARG_LEN - strlen(str))
+#define add_arg_str(str) \
 {\
 	const char *tmp = str;\
 	while (*tmp)\
 	{\
-		addArgChar(*(tmp++));\
+		add_arg_char(*(tmp++));\
 	}\
 }
 
-	*errorMsg = "";
+	*error_msg = "";
 	if (!command)
 	{
-		*errorMsg = "No command";
+		*error_msg = "No command";
 		return -1;
 	}
-	for (argc = 0; argc < maxArgc - 1; argc++)
+	for (argc = 0; argc < max_argc - 1; argc++)
 	{
-		int sQuote = 0;
+		int s_quote = 0;
 		argv[argc] = aptr;
-		while (isspace(theChar))
+		while (isspace(the_char))
 		{
-			advChar;
+			adv_char;
 		}
-		if (theChar == '\0')
+		if (the_char == '\0')
 		{
 			break;
 		}
-		while ((sQuote || !isspace(theChar)) &&
-		       theChar != '\0' && canAddArgChar)
+		while ((s_quote || !isspace(the_char)) &&
+		       the_char != '\0' && can_add_arg_char)
 		{
-			if (theChar == '"')
+			if (the_char == '"')
 			{
-				if (sQuote)
+				if (s_quote)
 				{
-					sQuote = 0;
+					s_quote = 0;
 				}
 				else
 				{
-					sQuote = 1;
+					s_quote = 1;
 				}
-				advChar;
+				adv_char;
 			}
-			else if (!sQuote && theChar == '\'')
+			else if (!s_quote && the_char == '\'')
 			{
-				advChar;
-				while (theChar != '\'' && theChar != '\0' &&
-				       canAddArgChar)
+				adv_char;
+				while (the_char != '\'' && the_char != '\0' &&
+				       can_add_arg_char)
 				{
-					addArgChar(popChar);
+					add_arg_char(pop_char);
 				}
-				if (theChar == '\'')
+				if (the_char == '\'')
 				{
-					advChar;
+					adv_char;
 				}
-				else if (!canAddArgChar)
+				else if (!can_add_arg_char)
 				{
 					break;
 				}
 				else
 				{
-					*errorMsg = "No closing single quote";
-					errorCode = -3;
+					*error_msg = "No closing single quote";
+					error_code = -3;
 					break;
 				}
 			}
-			else if (!sQuote && theChar == '~')
+			else if (!s_quote && the_char == '~')
 			{
-				if (!canAddArgStr(home_dir))
+				if (!can_add_arg_str(home_dir))
 				{
 					break;
 				}
-				addArgStr(home_dir);
-				advChar;
+				add_arg_str(home_dir);
+				adv_char;
 			}
-			else if (theChar == '$')
+			else if (the_char == '$')
 			{
 				int beg, len;
 				const char *str = getFirstEnv(cptr, &beg, &len);
 
 				if (!str || beg)
 				{
-					addArgChar(theChar);
-					advChar;
+					add_arg_char(the_char);
+					adv_char;
 					continue;
 				}
-				if (!canAddArgStr(str))
+				if (!can_add_arg_str(str))
 				{
 					break;
 				}
-				addArgStr(str);
+				add_arg_str(str);
 				cptr += len;
 			}
 			else
 			{
-				if (addArgChar(popChar) == '\0')
+				if (add_arg_char(pop_char) == '\0')
 				{
 					break;
 				}
@@ -460,43 +460,43 @@ static int parseCommandArgs(
 		}
 		if (*(aptr-1) == '\0')
 		{
-			*errorMsg = "Unexpected last backslash";
-			errorCode = -2;
+			*error_msg = "Unexpected last backslash";
+			error_code = -2;
 			break;
 		}
-		if (errorCode)
+		if (error_code)
 		{
 			break;
 		}
-		if (theChar == '~' || theChar == '$' || !canAddArgChar)
+		if (the_char == '~' || the_char == '$' || !can_add_arg_char)
 		{
-			*errorMsg = "The command is too long";
-			errorCode = -argc - 100;
+			*error_msg = "The command is too long";
+			error_code = -argc - 100;
 			break;
 		}
-		if (sQuote)
+		if (s_quote)
 		{
-			*errorMsg = "No closing double quote";
-			errorCode = -4;
+			*error_msg = "No closing double quote";
+			error_code = -4;
 			break;
 		}
-		addArgChar('\0');
+		add_arg_char('\0');
 	}
-#undef theChar
-#undef advChar
-#undef topChar
-#undef popChar
-#undef canAddArgChar
-#undef addArgChar
-#undef canAddArgStr
-#undef addArgStr
+#undef the_char
+#undef adv_char
+#undef top_char
+#undef pop_char
+#undef can_add_arg_char
+#undef add_arg_char
+#undef can_add_arg_str
+#undef add_arg_str
 	argv[argc] = NULL;
-	if (argc == 0 && !errorCode)
+	if (argc == 0 && !error_code)
 	{
-		*errorMsg = "Void command";
+		*error_msg = "Void command";
 	}
 
-	return errorCode ? errorCode : argc;
+	return error_code ? error_code : argc;
 }
 
 /*
@@ -541,21 +541,21 @@ char *get_display_name(char *display_name, int screen_num)
 /* if restart is true, command must not be NULL... */
 void Done(int restart, char *command)
 {
-	const char *exitFuncName;
+	const char *exit_func_name;
 
 	if (!restart)
 	{
 		MoveViewport(0,0,False);
 	}
 	/* migo (03/Jul/1999): execute [Session]ExitFunction */
-	exitFuncName = getInitFunctionName(2);
-	if (functions_is_complex_function(exitFuncName))
+	exit_func_name = get_init_function_name(2);
+	if (functions_is_complex_function(exit_func_name))
 	{
 		const exec_context_t *exc;
 		exec_context_changes_t ecc;
 
 		char *action = safestrdup(
-			CatString2("Function ", exitFuncName));
+			CatString2("Function ", exit_func_name));
 		ecc.type = restart ? EXCT_TORESTART : EXCT_QUIT;
 		ecc.w.wcontext = C_ROOT;
 		exc = exc_create_context(&ecc, ECC_TYPE | ECC_WCONTEXT);
@@ -574,7 +574,7 @@ void Done(int restart, char *command)
 	EWMH_ExitStuff();
 	if (restart)
 	{
-		Bool doPreserveState = True;
+		Bool do_preserve_state = True;
 		SaveDesktopState();
 
 		if (command)
@@ -585,7 +585,7 @@ void Done(int restart, char *command)
 			}
 			if (strncmp(command, "--dont-preserve-state", 21) == 0)
 			{
-				doPreserveState = False;
+				do_preserve_state = False;
 				command += 21;
 				while (isspace(command[0])) command++;
 			}
@@ -598,7 +598,7 @@ void Done(int restart, char *command)
 		/* won't return under SM on Restart without parameters */
 		RestartInSession(
 			restart_state_filename, command == NULL,
-			doPreserveState);
+			do_preserve_state);
 
 		/* RBW - 06/08/1999 - without this, windows will wander to
 		 * other pages on a Restart/Recapture because Restart gets the
@@ -622,16 +622,16 @@ void Done(int restart, char *command)
 		if (command)
 		{
 			char *my_argv[MAX_ARG_SIZE];
-			const char *errorMsg;
-			int n = parseCommandArgs(
-				command, my_argv, MAX_ARG_SIZE, &errorMsg);
+			const char *error_msg;
+			int n = parse_command_args(
+				command, my_argv, MAX_ARG_SIZE, &error_msg);
 
 			if (n <= 0)
 			{
 				fvwm_msg(
 					ERR, "Done",
 					"Restart command parsing error in"
-					" (%s): [%s]", command, errorMsg);
+					" (%s): [%s]", command, error_msg);
 			}
 			else if (strcmp(my_argv[0], "--pass-args") == 0)
 			{
@@ -828,6 +828,19 @@ InstallSignals(void)
 	return;
 }
 
+void fvmm_deinstall_signals(void)
+{
+	signal(SIGCHLD, SIG_DFL);
+	signal(SIGHUP, SIG_DFL);
+	signal(SIGINT, SIG_DFL);
+	signal(SIGPIPE, SIG_DFL);
+	signal(SIGQUIT, SIG_DFL);
+	signal(SIGTERM, SIG_DFL);
+	signal(SIGUSR1, SIG_DFL);
+
+	return;
+}
+
 /***********************************************************************
  *
  *  LoadDefaultLeftButton -- loads default left button # into
@@ -1060,7 +1073,6 @@ static void CreateGCs(void)
 {
 	XGCValues gcv;
 	unsigned long gcm;
-	XColor c;
 
 	/* create scratch GC's */
 	gcm = GCFunction|GCLineWidth;
@@ -1074,7 +1086,6 @@ static void CreateGCs(void)
 	Scr.TitleGC = fvwmlib_XCreateGC(dpy, Scr.NoFocusWin, gcm, &gcv);
 	Scr.BordersGC = fvwmlib_XCreateGC(dpy, Scr.NoFocusWin, gcm, &gcv);
 	Scr.TransMaskGC = fvwmlib_XCreateGC(dpy, Scr.NoFocusWin, gcm, &gcv);
-	c.pixel = GetColor(DEFAULT_FORE_COLOR);
 	Scr.ScratchMonoPixmap = XCreatePixmap(dpy, Scr.Root, 1, 1, 1);
 	Scr.MonoGC = fvwmlib_XCreateGC(dpy, Scr.ScratchMonoPixmap, gcm, &gcv);
 	Scr.ScratchAlphaPixmap = XCreatePixmap(
@@ -1136,13 +1147,7 @@ static void InitVariables(void)
 	Scr.CurrentDesk = 0;
 	Scr.EdgeScrollX = DEFAULT_EDGE_SCROLL * Scr.MyDisplayWidth / 100;
 	Scr.EdgeScrollY = DEFAULT_EDGE_SCROLL * Scr.MyDisplayHeight / 100;
-	Scr.ScrollResistance = DEFAULT_SCROLL_RESISTANCE;
-	Scr.MoveResistance = DEFAULT_MOVE_RESISTANCE;
-	Scr.XiMoveResistance = DEFAULT_XIMOVE_RESISTANCE;
-	Scr.SnapAttraction = DEFAULT_SNAP_ATTRACTION;
-	Scr.SnapMode = DEFAULT_SNAP_ATTRACTION_MODE;
-	Scr.SnapGridX = DEFAULT_SNAP_GRID_X;
-	Scr.SnapGridY = DEFAULT_SNAP_GRID_Y;
+	Scr.ScrollDelay = DEFAULT_SCROLL_DELAY;
 	Scr.OpaqueSize = DEFAULT_OPAQUE_MOVE_SIZE;
 	Scr.MoveThreshold = DEFAULT_MOVE_THRESHOLD;
 	/* ClickTime is set to the positive value upon entering the
@@ -1204,6 +1209,7 @@ static void InitVariables(void)
 	Scr.bo.do_disable_configure_notify = 0;
 	Scr.bo.do_install_root_cmap = 0;
 	Scr.bo.do_enable_flickering_qt_dialogs_workaround = 1;
+	Scr.bo.do_enable_qt_drag_n_drop_workaround = 0;
 	Scr.bo.do_enable_ewmh_iconic_state_workaround = 0;
 
 	Scr.gs.do_emulate_mwm = DEFAULT_EMULATE_MWM;
@@ -1376,11 +1382,14 @@ static void SetRCDefaults(void)
 		{ "TitleStyle Centered -- Raised", "", "" },
 		{ "Style * Color lightgrey/dimgrey", "", "" },
 		{ "Style * HilightFore black, HilightBack grey", "", "" },
+		{ "DestroyFunc FvwmMakeMissingDesktopMenu", "", "" },
+		{ "AddToFunc   FvwmMakeMissingDesktopMenu I PipeRead 'fvwm-menu-desktop --enable-mini-icons --fvwm-icons'", "", "" },
 		{
 			"AddToMenu MenuFvwmRoot \"",
 			_("Builtin Menu"),
 			"\" Title"
 		},
+                { "+ MissingSubmenuFunction FvwmMakeMissingDesktopMenu","",""},
 		{ "+ \"&1. XTerm\" Exec xterm", "", ""},
 		{
 			"+ \"&2. ",
@@ -1397,6 +1406,11 @@ static void SetRCDefaults(void)
 			_("Issue fvwm commands"),
 			"\" Module FvwmConsole"
 		},
+		{
+			"+ \"&D. ",
+			_("Desktop Menu"),
+			"\" Popup FvwmMenu"
+		},
 		{
 			"+ \"&R. ",
 			_("Restart fvwm"),
@@ -1505,8 +1519,8 @@ static int FvwmErrorHandler(Display *dpy, XErrorEvent *event)
 /* Does initial window captures and runs init/restart function */
 void StartupStuff(void)
 {
-#define startFuncName "StartFunction"
-	const char *initFuncName;
+#define start_func_name "StartFunction"
+	const char *init_func_name;
 	const exec_context_t *exc;
 	exec_context_changes_t ecc;
 
@@ -1548,19 +1562,19 @@ void StartupStuff(void)
 #endif
 
 	/* migo (04-Sep-1999): execute StartFunction */
-	if (functions_is_complex_function(startFuncName))
+	if (functions_is_complex_function(start_func_name))
 	{
-		char *action = "Function " startFuncName;
+		char *action = "Function " start_func_name;
 
 		execute_function(NULL, exc, action, 0);
 	}
 
 	/* migo (03-Jul-1999): execute [Session]{Init|Restart}Function */
-	initFuncName = getInitFunctionName(Restarting == True);
-	if (functions_is_complex_function(initFuncName))
+	init_func_name = get_init_function_name(Restarting == True);
+	if (functions_is_complex_function(init_func_name))
 	{
 		char *action = safestrdup(
-			CatString2("Function ", initFuncName));
+			CatString2("Function ", init_func_name));
 
 		execute_function(NULL, exc, action, 0);
 		free(action);
@@ -1583,6 +1597,11 @@ void StartupStuff(void)
 	}
 	exc_destroy_context(exc);
 
+	/* TA:  20091212:  If we get here, we're done restarting, so reset the
+	 * flag back to False!
+	 */
+	Restarting = False;
+
 	return;
 }
 
@@ -1692,21 +1711,21 @@ void SetMWM_INFO(Window window)
 }
 
 /*
- * setInitFunctionName - sets one of the init, restart or exit function names
- * getInitFunctionName - gets one of the init, restart or exit function names
+ * set_init_function_name - sets one of the init, restart or exit function names
+ * get_init_function_name - gets one of the init, restart or exit function names
  *
  * First parameter defines a function type: 0 - init, 1 - restart, 2 - exit.
  */
-void setInitFunctionName(int n, const char *name)
+void set_init_function_name(int n, const char *name)
 {
-	initFunctionNames[n >= 0 && n < 3? n: 3] = name;
+	init_function_names[n >= 0 && n < 3? n: 3] = name;
 
 	return;
 }
 
-const char *getInitFunctionName(int n)
+const char *get_init_function_name(int n)
 {
-	return initFunctionNames[n >= 0 && n < 3? n: 3];
+	return init_function_names[n >= 0 && n < 3? n: 3];
 }
 
 #ifndef _PATH_DEVNULL
@@ -2249,131 +2268,97 @@ int main(int argc, char **argv)
 		exit(1);
 	}
 
-	if (visualClass != -1)
 	{
-		/* grab the best visual of the required class */
-		XVisualInfo template, *vizinfo;
+		XVisualInfo template, *vinfo = NULL;
 		int total, i;
 
 		Pdepth = 0;
+		Pdefault = False;
+		total = 0;
 		template.screen = Scr.screen;
-		template.class = visualClass;
-		vizinfo = XGetVisualInfo(
-			dpy, VisualScreenMask | VisualClassMask, &template,
-			&total);
-		if (total)
+		if (visualClass != -1)
 		{
-			for (i = 0; i < total; i++)
+			template.class = visualClass;
+			vinfo = XGetVisualInfo(dpy,
+					VisualScreenMask|VisualClassMask,
+					&template, &total);
+			if (!total)
 			{
-				if (vizinfo[i].depth > Pdepth)
-				{
-					Pvisual = vizinfo[i].visual;
-					Pdepth = vizinfo[i].depth;
-				}
+				fvwm_msg(ERR, "main",
+					"Cannot find visual class %d",
+					visualClass);
 			}
-			XFree(vizinfo);
-			/* have to have a colormap for non-default visual
-			 * windows */
-			if (Pvisual->class == DirectColor)
-			{
-				Pcmap = XCreateColormap(
-					dpy, Scr.Root, Pvisual, AllocAll);
-			}
-			else
-			{
-				Pcmap = XCreateColormap(
-					dpy, Scr.Root, Pvisual, AllocNone);
-			}
-			Pdefault = False;
 		}
-		else
+		else if (visualId != -1)
 		{
-			fvwm_msg(
-				ERR, "main", "Cannot find visual class %d",
-				visualClass);
-			visualClass = -1;
+			template.visualid = visualId;
+			vinfo = XGetVisualInfo(dpy,
+					VisualScreenMask|VisualIDMask,
+					&template, &total);
+			if (!total)
+			{
+				fvwm_msg(ERR, "main",
+					"VisualId 0x%x is not valid ",
+					visualId);
+			}
 		}
-	}
-	else if (visualId != -1)
-	{
-		/* grab visual id asked for */
-		XVisualInfo template, *vizinfo;
-		int total;
 
-		Pdepth = 0;
-		template.screen = Scr.screen;
-		template.visualid = visualId;
-		vizinfo = XGetVisualInfo(
-			dpy, VisualScreenMask | VisualIDMask, &template,
-			&total);
-		if (total)
+		/* visualID's are unique so there will only be one.
+		   Select the visualClass with the biggest depth */
+		for (i = 0; i < total; i++)
 		{
-			/* visualID's are unique so there will only be one */
-			Pvisual = vizinfo[0].visual;
-			Pdepth = vizinfo[0].depth;
-			XFree(vizinfo);
-			/* have to have a colormap for non-default visual
-			 * windows */
-			if (Pvisual->class == DirectColor)
+			if (vinfo[i].depth > Pdepth)
 			{
-				Pcmap = XCreateColormap(
-					dpy, Scr.Root, Pvisual, AllocAll);
+				Pvisual = vinfo[i].visual;
+				Pdepth = vinfo[i].depth;
 			}
-			else
-			{
-				Pcmap = XCreateColormap(
-					dpy, Scr.Root, Pvisual, AllocNone);
-			}
-			Pdefault = False;
 		}
-		else
+		if (vinfo)
 		{
-			fvwm_msg(
-				ERR, "main", "VisualId 0x%x is not valid ",
-				visualId);
-			visualId = -1;
+			XFree(vinfo);
 		}
-	}
-
-	/* use default visuals if none found so far */
-	if (visualClass == -1 && visualId == -1)
-	{
-		Pdepth = 0;
 
 		/* Detection of a card with 2 hardware colormaps (8+24) which
 		 * use depth 8 for the default. We can use our own depth 24
 		 * cmap without affecting other applications. */
-		if (DefaultDepth(dpy, Scr.screen) <= 8)
+		if (Pdepth == 0 && DefaultDepth(dpy, Scr.screen) <= 8)
 		{
-			XVisualInfo template, *vizinfo = NULL;
-			int total,i;
-
-			template.screen = Scr.screen;
 			template.class = TrueColor;
-			vizinfo = XGetVisualInfo(
+			vinfo = XGetVisualInfo(
 				dpy, VisualScreenMask|VisualClassMask,
 				&template, &total);
+
 			for(i = 0; i<total; i++)
 			{
-				if (Pdepth < vizinfo[i].depth &&
-				    vizinfo[i].depth > 8)
+				if (Pdepth < vinfo[i].depth &&
+				    vinfo[i].depth > 8)
 				{
-					Pvisual = vizinfo[i].visual;
-					Pdepth = vizinfo[i].depth;
+					Pvisual = vinfo[i].visual;
+					Pdepth = vinfo[i].depth;
 				}
 			}
-			if (vizinfo)
+			if (vinfo)
 			{
-				XFree(vizinfo);
+				XFree(vinfo);
 			}
-			if (Pdepth > 0)
+		}
+
+		/* have to have a colormap for non-default visual windows */
+		if (Pdepth > 0)
+		{
+			if (Pvisual->class == DirectColor)
+			{
+				Pcmap = XCreateColormap(
+					dpy, Scr.Root, Pvisual, AllocAll);
+			}
+			else
 			{
 				Pcmap = XCreateColormap(
 					dpy, Scr.Root, Pvisual, AllocNone);
-				Pdefault = False;
 			}
 		}
-		if (Pdepth == 0)
+		/* use default visuals if none found so far */
+		else
 		{
 			Pvisual = DefaultVisual(dpy, Scr.screen);
 			Pdepth = DefaultDepth(dpy, Scr.screen);
