@@ -1,3 +1,4 @@
+/* -*-c-*- */
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -13,12 +14,11 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <stdlib.h>
-#include <string.h>
+#include "config.h"
 
 #include <gtk/gtk.h>
 
-#include <libs/fvwmlib.h>
+#include "libs/fvwmlib.h"
 
 
 typedef struct str_struct
@@ -127,11 +127,11 @@ recursive_replace (GtkWidget *d, char *val)
 	  nval = (char *) gtk_object_get_data (GTK_OBJECT (d), next->s);
 	  if (nval)
 	    {
-              /* this changes r->next, thus freeing next is safe */
+	      /* this changes r->next, thus freeing next is safe */
 	      tail = split_string (nval, r);
 	      tail->next = next->next;
 	      free (next->s);
-              free (next);
+	      free (next);
 	    }
 	  else
 	    {
