@@ -40,8 +40,9 @@
 #include "libs/fvwmlib.h"
 #include "libs/FScreen.h"
 #include "libs/FShape.h"
-#include <libs/Module.h>
+#include "libs/Module.h"
 #include "libs/Colorset.h"
+#include "libs/Graphics.h"
 #include "fvwm/fvwm.h"
 #include "libs/PictureGraphics.h"
 #include "FvwmPager.h"
@@ -173,7 +174,7 @@ static void do_scroll(int sx, int sy, Bool do_send_message,
 	}
 }
 
-void HandleScrollDone()
+void HandleScrollDone(void)
 {
 	do_scroll(0, 0, True, True);
 }
@@ -2196,27 +2197,28 @@ void MoveResizePagerView(PagerWindow *t, Bool do_force_redraw)
 }
 
 
-void MoveStickyWindows(void)
+void MoveStickyWindow(Bool is_new_page, Bool is_new_desk)
 {
-  PagerWindow *t;
+	PagerWindow *t;
 
-  t = Start;
-  while(t!= NULL)
-  {
-    if(((IS_ICONIFIED(t))&&(IS_ICON_STICKY_ACROSS_DESKS(t)))||
-       (IS_STICKY_ACROSS_DESKS(t)))
-    {
-      if(t->desk != Scr.CurrentDesk)
-      {
-	ChangeDeskForWindow(t,Scr.CurrentDesk);
-      }
-      else
-      {
-	MoveResizePagerView(t, True);
-      }
-    }
-    t = t->next;
-  }
+	for (t = Start; t != NULL; t = t->next)
+	{
+		if (
+			is_new_desk && t->desk != Scr.CurrentDesk &&
+			((IS_ICONIFIED(t) && IS_ICON_STICKY_ACROSS_DESKS(t)) ||
+			 IS_STICKY_ACROSS_DESKS(t)))
+		{
+			ChangeDeskForWindow(t, Scr.CurrentDesk);
+		}
+		else if (
+			is_new_page &&
+			((IS_ICONIFIED(t) &&
+			  IS_ICON_STICKY_ACROSS_PAGES(t)) ||
+			 IS_STICKY_ACROSS_PAGES(t)))
+		{
+			MoveResizePagerView(t, True);
+		}
+	}
 }
 
 void Hilight(PagerWindow *t, int on)
@@ -2888,7 +2890,7 @@ void PictureIconWindow (PagerWindow *t)
 
 void IconMoveWindow(XEvent *Event, PagerWindow *t)
 {
-	int x1, y1, finished = 0, wx, wy, n, x = 0, y = 0, xi = 0, yi = 0;
+	int x1, y1, finished = 0, n, x = 0, y = 0, xi = 0, yi = 0;
 	Window dumwin;
 	int m, n1, m1;
 	int moved = 0;
@@ -2906,8 +2908,6 @@ void IconMoveWindow(XEvent *Event, PagerWindow *t)
 	m = Scr.VyMax / Scr.MyDisplayHeight;
 	n1 = (Scr.Vx + t->x) / Scr.MyDisplayWidth;
 	m1 = (Scr.Vy + t->y) / Scr.MyDisplayHeight;
-	wx = (Scr.Vx + t->x) * (icon_w - n) / Scr.VWidth + n1;
-	wy = (Scr.Vy + t->y) * (icon_h - m) / Scr.VHeight + m1;
 
 	XRaiseWindow(dpy, t->IconView);
 
@@ -3298,7 +3298,7 @@ char *GetBalloonLabel(const PagerWindow *pw,const char *fmt)
 
 
 /* -- ric@giccs.georgetown.edu */
-void UnmapBalloonWindow ()
+void UnmapBalloonWindow (void)
 {
   XUnmapWindow(dpy, Scr.balloon_w);
   BalloonView = None;
